<?php

// declare(strict_types=1);

/**
 * This file is part of LEPTON Core, released under the GNU GPL
 * Please see LICENSE and COPYING files in your package for details, specially for terms and warranties.
 * 
 * NOTICE:LEPTON CMS Package has several different licenses.
 * Please see the individual license in the header of each single file or info.php of modules and templates.
 *
 * @author          LEPTON Project
 * @copyright       2010-2023 LEPTON Project
 * @link            https://lepton-cms.org
 * @license         https://gnu.org/licenses/gpl.html
 * @license_terms   please see LICENSE and COPYING files in your package
 *
 */


class LEPTON_core extends LEPTON_SecureCMS
{
    use LEPTON_singleton;

    public static $instance;

	public string $password_chars = 'a-zA-Z0-9\_\-\!\$\ยง\#\*\+';
	
    public static array $HEADERS = [
            'frontend' => [
                'css' => [],
                'js' => []
            ],
            'backend' => [
                'css' => [],
                'js' => []
            ]
        ];

    public static array $FOOTERS = [
            'frontend' => [
                'css' => [],
                'js' => []
            ],
            'backend' => [
                'css' => [],
                'js' => []
            ]
        ];	

    /**
	 *  Constructor of the class
	 */
	public function __construct()
	{

	}
	
	/**
	 *  Check whether a page is visible or not.
	 *  This will check page-visibility and user- and group-rights.
	 *
	 *  @return bool false: if page-visibility is 'none' or 'deleted', or page-vis. is 'registered' or 'private' and user isn't allowed to see the page.
     *               true: if page-visibility is 'public' or 'hidden', or page-vis. is 'registered' or 'private' and user _is_ allowed to see the page.
	 *
	 */
	public function page_is_visible( $page ): bool
	{
		// First check if visibility is 'none', 'deleted'

        $show_it = false;
        switch ($page['visibility'])
		{
			case 'hidden':
			case 'public':
				$show_it = true;
				break;

			case 'private':
			case 'registered':
				if ($this->is_authenticated() === true)
				{
					$show_it = ($this->is_group_match($this->get_groups_id(), $page['viewing_groups']) || $this->is_group_match($this->get_user_id(), $page['viewing_users']));
				}
				break;

            case 'none':
            case 'deleted':
            default:
				$show_it = false;
				break;				
		}

        return ($show_it);
	}
	
	/**
	 *  Check if a given section is active.
	 *
	 *  @param  int $section_id A valid section_id.
	 *  @return boolean             True if the section is active, otherwise false.
	 *
	 */
    public function section_is_active(int $section_id): bool
	{
		$now = time();
		$sql = "
		    SELECT COUNT(*) 
		    FROM    `" . TABLE_PREFIX . "sections` 
		    WHERE   (" . $now . " BETWEEN `publ_start` AND `publ_end`) 
		        OR  (" . $now . " > `publ_start` AND `publ_end`=0) 
		        AND `section_id`=" . $section_id;

        return (LEPTON_database::getInstance()->get_one($sql) !== false); // [#1] Why not '0'? as we are "counting"!
	}
	
	/**
	 *  Check if there is at least one active section on this page.
	 *
	 *  @param  array   $page   An assoc. array with the page-values.
	 *  @return boolean         True there is at least one active section on this page, otherwise false.
	 *
	 */
	public function page_is_active(array $page ): bool
	{
		$now = time();
		$sql = "
		    SELECT COUNT(*) 
		    FROM `" . TABLE_PREFIX . "sections`
		    WHERE (" . $now . " BETWEEN `publ_start` AND `publ_end`) 
		        OR (" . $now . " > `publ_start` AND `publ_end`=0)
		        AND `page_id`=" . intval( $page[ 'page_id' ] );
		        
		return ( LEPTON_database::getInstance()->get_one( $sql ) !== false ); // [#1.1] Same as above in [#1]: why not '0'? as we are "counting"!
	}
	
	/**
	 *  Check whether we should show a page or not (for front-end).
	 *
	 *  @param  array|null   $page   An assoc. array with the page-values.
	 *  @return boolean         True there is at least one active section on this page, otherwise false.
	 */
	public function show_page(array|null $page ): bool
	{
        if (!is_array($page))
		{
			$page = [];
			LEPTON_database::getInstance()->execute_query(
			    "SELECT `page_id`, `visibility`, `viewing_groups`, `viewing_users` FROM `" . TABLE_PREFIX . "pages` WHERE `page_id`=" . (int) $page,
			    true, 
			    $page,
			    false
			);
			
			if (empty($page))
			{
                return false;
			}
		}
		return ($this->page_is_visible($page) && $this->page_is_active($page));
	}
	
	// Check if the user is already authenticated or not
	public function is_authenticated(): bool
	{
		return (    (isset( $_SESSION[ 'USER_ID' ] ) )      // gesetzt
		        &&  ($_SESSION[ 'USER_ID' ] != "")          // nicht leer
		        &&  (is_numeric( $_SESSION[ 'USER_ID' ] ) ) // eine Zahl
		);
	}
	
	public function page_link(string $link): string
	{
        ob_start();
        debug_print_backtrace(DEBUG_BACKTRACE_IGNORE_ARGS, 2);
        $trace = str_replace(LEPTON_PATH, "", ob_get_clean());
		echo LEPTON_tools::display(
            "Warning - page_link is deprecated and will be removed in L*6.1.x! Use 'buildPageLink' instead!<br>" . $trace,
            "pre",
            "ui message red"
        );


        return $this->buildPageLink($link);
	}

    /**
     * Returns the full URL to a given page(-link).
     * Takes care for 'mailto:' links and even qualified links.
     *
     * @param string $link
     * @return string
     */
    public function buildPageLink(string $link): string
    {
        // Check for :// in the link (used in URL's) as well as mailto:
        if (strstr($link, '://') == '' && !str_starts_with($link, 'mailto:'))
        {
            return LEPTON_URL . PAGES_DIRECTORY . $link . PAGE_EXTENSION;
        }
        else
        {
            return $link;
        }
    }

    // Get POST data
    public function get_post(string|array $field): string|int|array|null
    {
        return $_POST[$field] ?? null;
    }
	
	/**
	 *	Get data from $_POST and try to escape it.
	 *	When 'field' is an array - each element will be escaped.
	 */
	public function get_post_escaped(string|array|null $field): string|array|null
    {
        $result = $this->get_post($field);
        if (is_array($result))
        {
            return array_map("addslashes", $result);
        }
        return (is_null($result)) ? null : addslashes($result);
	}
	
	// Get $_GET data
	public function get_get(string $field): mixed
	{
		return $_GET[$field] ?? null;
	}
	
	// Get SESSION data
	public function get_session(string $field): int|string|array|null
	{
		return $_SESSION[$field] ?? null;
	}
	
	// Get SERVER data
	public function get_server(string $field): int|string|array|null
	{
		return $_SERVER[$field] ?? null;
	}
	
	// Get the current users id
	public function get_user_id()
	{
		return $_SESSION['USER_ID'] ?? '';
	}
	
	// Get the current users group id (deprecated)
	public function get_group_id()
	{
		return $_SESSION['GROUP_ID'] ?? '';
	}
	
	// Get the current users group ids
	public function get_groups_id(): array
	{
		return explode( ",", $_SESSION['GROUPS_ID'] ?? '');
	}
	
	// Get the current users group name
	public function get_group_name(): string
	{
        return implode(",", $_SESSION['GROUP_NAME']);
	}
	
	// Get the current users group name
	public function get_groups_name(): string
	{
		return $_SESSION['GROUP_NAME'] ?? '';
	}
	
	// Get the current users username
	public function get_username(): string
	{
		return $_SESSION['USERNAME'] ?? '';
	}
	
	// Get the current users display name
	public function get_display_name(): string
	{
		return $_SESSION['DISPLAY_NAME'] ?? '';
	}
	
	// Get the current users email address
	public function get_email(): string
	{
		return $_SESSION['EMAIL'] ?? '';
	}
	
	// Get the current users home folder
	public function get_home_folder(): string
	{
		return $_SESSION['HOME_FOLDER'] ?? '';
	}
	
	// Get the current users timezone
	public function get_timezone_string(): string
	{
		return $_SESSION['TIMEZONE_STRING'] ?? DEFAULT_TIMEZONE_STRING;
	}
	
	/* ****************
	 * check if one or more group_ids are in both group_lists
	 *
	 * @access public
	 * @param mixed $groups_list1: an array or a coma seperated list of group-ids
	 * @param mixed $groups_list2: an array or a coma seperated list of group-ids
	 * @return bool: true there is a match, otherwise false
	 */
    public function is_group_match(string|array $groups_list1 = '', string|array $groups_list2 = ''): bool
	{
        if ($groups_list1 == '')
		{
			return false;
		}
        if ($groups_list2 == '')
		{
			return false;
		}
        if (!is_array($groups_list1))
		{
			$groups_list1 = explode( ',', $groups_list1 );
		}
        if (!is_array($groups_list2))
		{
			$groups_list2 = explode( ',', $groups_list2 );
		}

        return (sizeof(array_intersect($groups_list1, $groups_list2)) != 0);
    }
	
	/** ****************
	 * Check if current user is member of at least one of given groups
	 * ADMIN (uid=1) always is treated like a member of any groups
	 *
	 * @access public
	 * @param string|array $groups_list an array or a coma seperated list of group-ids
	 * @return bool true if current user is member of one of these groups, otherwise false
	 */
	public function ami_group_member(string|array $groups_list = ''): bool
	{
        if ($this->get_user_id() == 1)
		{
			return true;
		}
        return $this->is_group_match($groups_list, $this->get_groups_id());
	}
	
    /**
     * Internal function, only used for get_page_headers and get_page_footers
     *
     * @param string $for
     * @param string $path
     * @param bool $footer
     * @return void
     */
    public static function addItems(string $for = 'frontend', string $path = LEPTON_PATH, bool $footer = false): void
	{
        $trail = explode('/', $path);
        $subdir = array_pop($trail);
	
		$mod_headers = [];
		$mod_footers = [];

        if ($footer)
		{
			$add_to = &self::$FOOTERS;
			$to_load = 'footers.inc.php';
		}
		else
		{
			$add_to = &self::$HEADERS;
			$to_load = 'headers.inc.php';
		}

        require $path . '/' . $to_load;

        if (true === $footer)
		{
			$aRefArray = &$mod_footers;
		}
		else
		{
			$aRefArray = &$mod_headers;
		}

        if (count($aRefArray))
		{
            foreach (['css', 'js'] as $key)
			{
                if (!isset($aRefArray[$for][$key]))
				{
					continue;
				}
                foreach ($aRefArray[$for][$key] as &$item)
				{
					// let's see if the path is relative (i.e., does not contain the current subdir)
                    if ((isset($item['file']))
                        && (!preg_match("#/$subdir/#", $item['file']))
                        && (file_exists($path . '/' . $item['file']))
					)
					{
						// treat path as relative, add modules subfolder
                        $item['file'] = str_ireplace(LEPTON_PATH, '', $path) . '/' . $item['file'];
					}
					
					$is_ok = true;
                    if ($key === "css") {
						foreach($add_to[ $for ][ $key ] as $temp_ref)
						{
                            if ($temp_ref['file'] == $item['file'])
							{
								$is_ok = false;
							}
						}
                    } elseif ($key === "js")
					{
						foreach($add_to[ $for ][ $key ] as $temp_ref)
						{
                            if ($item === $temp_ref)
							{
								$is_ok = false;
							}
						}
					
					}

                    if (true === $is_ok)
					{
                        $add_to[$for][$key][] = $item;
					}
				}
			}
		}

        if ($footer && file_exists($path . $for . '_body.js'))
		{
            $add_to[$for]['js'][] = '/modules/' . $subdir . '_body.js';
		}
		
	}	


	/**
	*    @internal call for protected functions
	*/
	public function getProtectedFunctions( &$html, &$sf )
	{	
		$this->addTokens( $html, $sf );
	}

	/**
	*    @param    string  $html    The hole HTML page. Call by reference.
	*    @param    object  $sf      Ref. of a given admin-object instance. Call by reference.
	*/
    protected function addTokens(string &$html, object &$sf): void
	{
        /**
         * @notice Aldus: 2022-11-12 - It is not clear wherever the LEPTOKEN_LIFETIME is handled inside L* VI
		 * @notice erpe: 2023-01-17 - seems that this is handled in LEPTON_securecms (public function checkToken()) and LEPTON_admin (line 189)
         */
        if (!LEPTOKEN_LIFETIME)
        {
            return;
        }

        $token = $sf->getToken();

        $token1      = "$1?leptoken=".$token."$3"; // no parameters so far
        $token2      = "leptoken=".$token; // for replacing placeholder in JS functions
        $token3      = "$1&leptoken=".$token."$3"; // with existing parameters, produces html-valid code
        $token4      = "$1?leptoken=".$token."$2"; // for special cases
        $hiddentoken = "$1\n<span><input type='hidden' name='leptoken' value='".$token."' /></span>\n"; // for GET forms, add a hidden field too

        // finds absolute Links with Parameter:
        $qs   = '~((href|action|window\.location)\s?=\s?[\'"]' . LEPTON_URL . '[\w\-\./]+\.php\?[\w\-\.=&%;/]+)([#[\w]*]?[\'"])~';
        $html = preg_replace( $qs, $token3, $html, -1 );

        // finds absolute Links without Parameter:
        $qs   = '~((href|action|ajaxfilemanagerurl|window\.location)\s?=\s?[\'"]' . LEPTON_URL . '[\w\-\./]+\.php)([#[\w]*]?[\'"])~';
        $html = preg_replace( $qs, $token1, $html, -1 );

        // finds relative Links with Parameter:
        $qs   = '~((href|action|window\.location)\s?=\s?[\'"][\w/]+\.php\?[\w\-\.=%&;/]+)([#[\w]*]?[\'"])~';
        $html = preg_replace( $qs, $token3, $html, -1 );

        // finds relative Links without Parameter:
        $qs   = '~((href|action|window\.location)\s?=\s?[\'"][\w/]+\.php)([#[\w]*]?[\'"])~';
        $html = preg_replace( $qs, $token1, $html, -1 );

        // finds Start page without Parameter:
        $qs   = '~(href\s?=\s?[\'"]' . LEPTON_URL . ')([\'"])~';
        $html = preg_replace( $qs, $token4, $html, -1 );

        // finds Testmail in Options:
        $qs   = '~(send_testmail\(\'' . ADMIN_URL . '/settings/ajax_testmail\.php)(\'\))~';
        $html = preg_replace( $qs, $token4, $html, -1 );

        // finds forms with method=get and adds a hidden field
        $qs   = '~(<form\s+action=[\'"][\w:\.\?/]+leptoken=\w{32}[\'"]\s+method=[\'"]get[\'"]\s*>)~';
        $html = preg_replace( $qs, $hiddentoken, $html, -1 );

        // set leptoken in JS functions
        $qs   = '~leptokh=#-!leptoken-!#~';
        $html = preg_replace( $qs, $token2, $html, -1 );	
	}


    /**
     * Create directories recursive
     *
     * @param string $dir_name - directory to create
     * @param string|null $dir_mode - access mode
     * @return boolean result of operation
     */
	 
	static public function make_dir(string $dir_name, string $dir_mode = NULL): bool
	{
        if ($dir_mode == NULL)
		{
			$dir_mode = (int) octdec( STRING_DIR_MODE );
		}
		
		if (!is_dir($dir_name))
		{
			$umask = umask(); // get current mask
			mkdir($dir_name, $dir_mode, true);
			umask($umask);
			return true;
		}
		return false;
	}
	
	/**
	 * not used on Windows Systems, values from table settings
	 *
	 * @access public
	 * @param  string   $name - directory or file
	 * @return bool
	 *
	 **/
	static public function change_mode(string $name ): bool
	{
        if (OPERATING_SYSTEM != 'windows')
		{
            $mode = (is_dir($name)) ? (int)octdec(STRING_DIR_MODE) : (int)octdec(STRING_FILE_MODE);
            if (file_exists($name))
			{
				$umask = umask();       // get current
                chmod($name, $mode);
                umask($umask);
				return true;
			}
			else
			{
				return false;
			}
		}
		else
		{
			return true;
		}
	}


    /**
     * Creates a new access file for a given page_id.
     *
     * @param string    $filename  Full path
     * @param int       $page_id      Internal page_id
     * @return bool     True if success.
     */
    static public function create_access_file(string $filename, int $page_id): bool
	{
		global $admin, $MESSAGE;
        $pages_path = LEPTON_PATH . PAGES_DIRECTORY;
        $rel_pages_dir = str_replace($pages_path, '', dirname($filename));
        $rel_filename = str_replace($pages_path, '', $filename);
        // root_check prevent system directories and important files from being overwritten if PAGES_DIR = '/'
        $denied = false;
        if (PAGES_DIRECTORY == '')
		{
			$forbidden = [
				'account',
				'admins',
				'framework',
				'include',
				'install',
				'languages',
				'media',
				'modules',
				'page',
				'search',
				'temp',
				'templates',
				'index.php',
				'/config/config.php'
			];
            $search = explode('/', $rel_filename);
			// we need only the first level
            $denied = in_array($search[1], $forbidden);
		}
        if ((true === is_writable($pages_path)) && (false === $denied))
		{
			// First make sure parent folder exists
            $parent_folders = explode('/', $rel_pages_dir);
            $parents = '';
            foreach ($parent_folders as $parent_folder)
			{
                if ($parent_folder != '/' && $parent_folder != '')
				{
                    $parents .= '/' . $parent_folder;
                    if (!file_exists($pages_path . $parents))
					{
						LEPTON_core::make_dir( $pages_path . $parents );
						LEPTON_core::change_mode( $pages_path . $parents );
					}
				}
			}
            $step_back = str_repeat('../', substr_count($rel_pages_dir, '/') + (PAGES_DIRECTORY == "" ? 0 : 1));
			$content   = '<?php' . "\n";
			$content .= "/**\n *\tThis file is autogenerated by LEPTON - Version: ".LEPTON_VERSION."\n";
			$content .= " *\tDo not modify this file!\n */\n";
			$content .= "\t" . '$page_id = ' . $page_id . ';' . "\n";
			$content .= "\t" . 'require_once(\'' . $step_back . 'index.php\');' . "\n";

			/**
			 *  write the file
			 *
			 */
            $fp = fopen($filename, 'w');
            if ($fp)
			{
                fwrite($fp, $content, strlen($content));
                fclose($fp);
				/**
				 *  Chmod the file
				 *
				 */
                LEPTON_core::change_mode($filename);
				/**
				 *	Looking for the index.php inside the current directory.
				 *	If not found - we just copy the master_index.php from the admin/pages
				 *
				 */
				$temp_index_path = dirname( $filename ) . "/index.php";
                if (!file_exists($temp_index_path))
				{
					$origin = ADMIN_PATH . "/pages/master_index.php";
                    if (file_exists($origin))
					{
                        copy($origin, $temp_index_path);
					}
				}
			}
			else
			{
                $admin->print_error($MESSAGE['PAGES_CANNOT_CREATE_ACCESS_FILE'] . "<br />Problems while trying to open the file!");
                return false;
			}
            return true;
		}
		else
		{
            $admin->print_error($MESSAGE['PAGES_CANNOT_CREATE_ACCESS_FILE']);
			return false;
		}
	}

	/**
	 * Counts the levels from given page_id to root
	 *
	 * @access public
	 * @param  int  $iPageId
	 * @return int  The current level of the given page_id >== 0
	 *
	 **/
	static public function level_count(int $iPageId ): int
	{
		$database = LEPTON_database::getInstance();
		// Get page parent
		$iParent = $database->get_one('SELECT `parent` FROM `' . TABLE_PREFIX . 'pages` WHERE `page_id` = '.$iPageId);
        if ($iParent > 0)
		{
			// Get the level of the parent
            $iLevel = $database->get_one('SELECT `level` FROM `' . TABLE_PREFIX . 'pages` WHERE `page_id` = ' . $iParent);
			return $iLevel + 1;
		}
		else
		{
			return 0;
		}
	}


	/**
	 *	Function to get all sub-pages id's from a given page id.
	 *
	 *	@param	int     $parent A valid page_id as 'root'.
	 *	@param	array   $subs   A given linear array to store the results. Call-by-reference!
	 *
	 *	@return	void	Keep in mind, that param "subs" is passed-by-reference!
	 *
	 *	@example	$all_subpages_ids = [];
	 *				LEPTON_core::get_subs( 5, $all_subpages_ids);
	 *
	 *				Will result in a linear list like e.g. "[5,6,8,9,11,7]" as the sub-ids
	 *				are sorted by position (in the page-tree);
	 *
	 */
    static public function get_subs(int $parent, array &$subs): void
	{
		$database = LEPTON_database::getInstance();

		// Get id's
		$all = [];
		$database->execute_query( 
			'SELECT `page_id` FROM `' . TABLE_PREFIX . 'pages` WHERE `parent` = ' . $parent." ORDER BY `position`",
			true,
			$all,
			true
		);

        foreach ($all as &$fetch)
		{
            $subs[] = $fetch['page_id'];
			
			// Get subs of this sub - recursive call!
            self::get_subs($fetch['page_id'], $subs);
		}
	}
	
	
	/**
	 * Delete a page
	 *
	 * @access public
	 * @param  integer $page_id
	 * @return void
	 *
	 **/
	static public function delete_page(int $page_id): void
	{
        $database = LEPTON_database::getInstance();
        $admin = self::getGlobal('admin');
        $MESSAGE = self::getGlobal('MESSAGE');
        $section_id = self::getGlobal('section_id');

		// Find out more about the page
		$page_info = [];
		$database->execute_query(
			'SELECT `link`, `parent` FROM `' . TABLE_PREFIX . 'pages` WHERE `page_id` = ' . $page_id,
			true,
			$page_info,
			false
		);

        if (empty($page_info))
		{
            $admin->print_error($MESSAGE['PAGES_NOT_FOUND']);
		}

		// Get the sections that belong to the page
		$all_sections = [];
		$database->execute_query(
			'SELECT `section_id`, `module` FROM `' . TABLE_PREFIX . 'sections` WHERE `page_id` = ' . $page_id,
			true,
			$all_sections
		);

		foreach($all_sections as &$section)
		{
			// Set section id
			$section_id = $section[ 'section_id' ];
				
			// Include the modules delete file if it exists
            if (file_exists(LEPTON_PATH . '/modules/' . $section['module'] . '/delete.php'))
			{
				include LEPTON_PATH . '/modules/' . $section[ 'module' ] . '/delete.php';
			}
		}
		
		// Update the pages table
        $database->simple_query("DELETE FROM " . TABLE_PREFIX . "pages WHERE page_id = " . $page_id);
		
		// Update the sections table
        $database->simple_query("DELETE FROM " . TABLE_PREFIX . "sections WHERE page_id = " . $page_id);

		
		// Include the ordering class or clean-up ordering
        $order = new LEPTON_order(TABLE_PREFIX . 'pages', 'position', 'page_id', 'parent');
        $order->clean($page_info['parent']);
		
		// Unlink the page access file and directory
		$directory = LEPTON_PATH . PAGES_DIRECTORY . $page_info['link'];
		$filename  = $directory . PAGE_EXTENSION;
		$directory .= '/';
        if (file_exists($filename))
		{
            if (!is_writable(LEPTON_PATH . PAGES_DIRECTORY . '/'))
			{
                $admin->print_error($MESSAGE['PAGES_CANNOT_DELETE_ACCESS_FILE']);
			}
			else
			{
                unlink($filename);
                if (file_exists($directory) && (rtrim($directory, '/') != LEPTON_PATH . PAGES_DIRECTORY) && ($page_info['link'][0] != '.'))
				{
                    rm_full_dir($directory);
				}
			}
		}
	}

    /**
     * @param string $name
     * @return int|string|array|object|null
     */
    static public function getGlobal(string $name): null|int|string|array|object
    {
        $returnValue = null;
        if (isset($GLOBALS[$name]))
        {
            $returnValue = &$GLOBALS[$name];
        }
        return $returnValue;
    }
	
    /**
     * Basic functions are used for both: frontend and backend.
     *
     * @return void
     */
    static function registerBasicFunctions(): void
    {
        $functionListToRegister = [
            "get_page_headers",
            "get_page_footers",
            "page_content",
            "easymultilang_menu",
            "rm_full_dir",
            "mod_file_exists",
            "toggle_css_file"
        ];

        LEPTON_handle::register($functionListToRegister);
    }

    /**
     * From this time on we can also use code snippets in the backend.
     *
     * @since LEPTON-CMS 6.0
     * @return void
     */
    static function loadCodeSnippets(): void
    {
        $snippets = [];
        LEPTON_database::getInstance()->execute_query(
            "SELECT `directory` FROM `" . TABLE_PREFIX . "addons` WHERE function='snippet'",
            true,
            $snippets,
            true
        );

        foreach ($snippets as $snippet) {
            $tempPath = LEPTON_PATH . "/modules/" . $snippet['directory'] . "/include.php";
            if (file_exists($tempPath)) {
                require $tempPath;
            }
        }
    }	
}
