<?php

// declare(strict_types=1);

/**
 * This file is part of LEPTON Core, released under the GNU GPL
 * Please see LICENSE and COPYING files in your package for details, specially for terms and warranties.
 * 
 * NOTICE:LEPTON CMS Package has several different licenses.
 * Please see the individual license in the header of each single file or info.php of modules and templates.
 *
 * @author          LEPTON Project
 * @copyright       2010-2023 LEPTON Project
 * @link            https://lepton-cms.org
 * @license         https://gnu.org/licenses/gpl.html
 * @license_terms   please see LICENSE and COPYING files in your package
 *
 */


/**
 *	@notice		Please keep in mind, that class "frontend" extends class "LEPTON_core"
 *
 */
class LEPTON_frontend extends LEPTON_core
{
    use LEPTON_singleton;

	static $instance;
	
	// defaults
	public string $default_link = "/";
	public int $default_page_id = 1;
	
	// when multiple blocks are used, show home page blocks on 
	// pages where no content is defined (search, login, ...)
	public bool $default_block_content = true;
	
	// page details
	public array $page = [];
	public int $page_id = 0;
	
	public array $page_trail = array();
	
	public bool $page_access_denied = false;
	public bool $page_no_active_sections = false;

    public function __construct()
    {	
        self::$instance = $this;
		if (TFA != 'none')	// first step in process to display page and set vars
		{			
			if (!isset($_SESSION['USER_ID']))
			{
				$pin_set = -1;
			}
			else
			{
				$pin_set = LEPTON_database::getInstance()->get_one("SELECT pin_set FROM ".TABLE_PREFIX."users WHERE user_id = '".$_SESSION['USER_ID']."' ");
				
			}
			
			switch ($pin_set )
			{
				case 0:
				case 1:
					header('Location: '.LEPTON_URL.'/account/logout.php');
					break;    
				
				case -1:
				case 2:
					LEPTON_SecureCMS::clearTokens();
					break; 					
				
				default:
					LEPTON_SecureCMS::clearTokens();
					header('Location: '.LEPTON_URL.'/account/logout.php');		
			}	
		}		
    }
	
	public function page_select()
	{
		global $page_id;

		// Check if we should add page language sql code
		$sql_where_language = (PAGE_LANGUAGES) ? " AND language = '" . LANGUAGE . "'" : "";
		
		// Get default page
		$now            = time();
		$query_default  = "
		    SELECT      * 
		    FROM        `".TABLE_PREFIX . "pages` AS `p` 
		    INNER JOIN  `".TABLE_PREFIX . "sections`
		    
		    USING(`page_id`)
		    
		    WHERE   `parent` = '0' 
		        
		    AND `visibility` = 'public'	
		    
		    AND (
		            (".$now." >= `publ_start` OR `publ_start` = 0) 
		        AND 
		            (".$now." <= `publ_end` OR `publ_end` = 0)
		    )
		    ".$sql_where_language."
            ORDER BY
                `p`.`position`
            
            ASC LIMIT 1
        ";
		
		$fetch_default = [];
		LEPTON_database::getInstance()->execute_query(
		    $query_default,
		    true,
		    $fetch_default,
		    false
		);
		
		if ( !isset( $page_id ) || !is_numeric( $page_id ) )
		{
			// Display default page
			if (!empty($fetch_default))
			{
				$this->default_link    = $fetch_default[ 'link' ];
				$this->default_page_id = intval($fetch_default[ 'page_id' ]);
				
				// Check if we should redirect or include page inline
				if ( HOMEPAGE_REDIRECTION )
				{
					// Redirect to page
					header( "Location: " . $this->buildPageLink( $this->default_link ) );
					exit();
				}
				else
				{
					// Include page inline
					$this->page_id = $this->default_page_id;
				}
			}
			else
			{
				exit();
			}
		}
		else
		{
			if(!isset($fetch_default[ 'link' ]))
			{
				die(LEPTON_tools::display('This installation has no content yet', 'pre','ui red message'));
			}
						
			$this->page_id = $page_id;
            $this->default_link     = $fetch_default[ 'link' ];
            $this->default_page_id  = intval($fetch_default[ 'page_id' ]);
            $this->page             = $fetch_default;

		}
		return true;
	}
	
	public function get_page_details()
	{
        if ($this->page_id != 0)
		{
			$this->page = [];
			$query_page = "SELECT * FROM `" . TABLE_PREFIX . "pages` WHERE `page_id` = ".$this->page_id;
			LEPTON_database::getInstance()->execute_query(
			    $query_page,
			    true,
			    $this->page,
			    false
			);
			
			// Make sure page was found in database
			if (empty($this->page))
			{
				// Print page not found message
				exit( "Page not found." );
			}
			else
			{
				foreach ($this->page as $key => $value)
				{
					// set members of array to constants
					$key = strtoupper($key);
					if (!defined($key))
					{			
						if ($key === 'TEMPLATE' && empty($value))
						{						
							$value = LEPTON_database::getInstance()->get_one("SELECT value FROM ".TABLE_PREFIX."settings WHERE name = 'default_template' ");
						}
						
						if ($key === 'DESCRIPTION' && empty($value))
						{						
							$value = WEBSITE_DESCRIPTION;
						}
						
						if ($key === 'KEYWORDS' && empty($value))
						{						
							$value = WEBSITE_KEYWORDS;
						}						
						
						define($key, $value);
					}
				}
			}
			
			// Check if the page language is also the selected language. If not, send headers again.
			if ( $this->page[ 'language' ] != LANGUAGE )
			{
				if ( isset( $_SERVER[ 'QUERY_STRING' ] ) && $_SERVER[ 'QUERY_STRING' ] != '' ) // check if there is a query-string
				{
					header( 'Location: ' . $this->buildPageLink( $this->page[ 'link' ] ) . '?' . $_SERVER[ 'QUERY_STRING' ] . '&lang=' . $this->page[ 'language' ] );
				}
				else
				{
					header( 'Location: ' . $this->buildPageLink( $this->page[ 'link' ] ) . '?lang=' . $this->page[ 'language' ] );
				}
				exit();
			}

			// Page trail
			foreach ( explode( ',', $this->page[ 'page_trail' ] ) AS $pid )
			{
				$this->page_trail[ $pid ] = $pid;
			}					
		}
				
		
		// Set the template dir
		if(!defined('TEMPLATE'))
		{
			define('TEMPLATE', DEFAULT_TEMPLATE);
		}
		define( 'TEMPLATE_DIR', LEPTON_URL . '/templates/' . TEMPLATE );
		// Check if user is allowed to view this page
		if ($this->page_is_visible($this->page) === false)
		{
			if ( VISIBILITY == 'deleted' || VISIBILITY == 'none' )
			{
				// User isn't allowed on this page so tell them
				$this->page_access_denied = true;
			}
			elseif ( VISIBILITY == 'private' || VISIBILITY == 'registered' )
			{
				// Check if the user is authenticated
				if ( $this->is_authenticated() === false )
				{
					// User needs to log-in first
					header( "Location: " . LEPTON_URL . "/account/login.php?redirect=" . $this->buildPageLink($this->page['link']) );
					exit( 0 );
				}
				else
				{
					$temp_array = explode(',',$this->page['viewing_groups']);
					if(in_array( $_SESSION['GROUP_ID'],$temp_array)) {
						
						$this->page_access_denied = false;
					}
					else
					{
						// User is not allowed on this page so tell them
						$this->page_access_denied = true;
					}		
				}
													
			}
		}

        $this->maintainConstants();

		// check if there is at least one active section
        if ($this->page_is_active($this->page) === false)
		{
			$this->page_no_active_sections = true;
		}
	}
	
	public function get_website_settings()
	{				
		// Work-out if any possible in-line search boxes should be shown
		if ( SEARCH == 'public' )
		{
			define( 'SHOW_SEARCH', true );
		}
		elseif ( SEARCH == 'private' && VISIBILITY == 'private' )
		{
			define( 'SHOW_SEARCH', true );
		}
		elseif ( SEARCH == 'private' && $this->is_authenticated() === true )
		{
			define( 'SHOW_SEARCH', true );
		}
		elseif ( SEARCH == 'registered' && $this->is_authenticated() === true )
		{
			define( 'SHOW_SEARCH', true );
		}
		else
		{
			define( 'SHOW_SEARCH', false );
		}
		// Work-out if menu should be shown
		if ( !defined( 'SHOW_MENU' ) )
		{
			define( 'SHOW_MENU', true );
		}
		// Work-out if login menu constants should be set
		if ( FRONTEND_LOGIN )
		{
			// Set login menu constants
			define( 'LOGIN_URL', LEPTON_URL . '/account/login.php' );
			define( 'LOGOUT_URL', LEPTON_URL . '/account/logout.php' );
			define( 'FORGOT_URL', LEPTON_URL . '/account/forgot.php' );
			define( 'PREFERENCES_URL', LEPTON_URL . '/account/preferences.php' );
			define( 'SIGNUP_URL', LEPTON_URL . '/account/signup.php' );
		}
	}
	
	/**
	 *	replace all "[LEPTONlink{page_id}]" with real links
	 *	@param	string &$content : reference to global $content
	 *	@return	void
	 */
    public function preprocess(string &$content): void
	{
		$database = LEPTON_database::getInstance();
		$content = str_ireplace( ["%5B","%5D"], ["[", "]"], $content);

		// starting with L*5 LEPTON_link replaces lepton-link
        if (preg_match_all('/\[LEPTONlink([0-9]+)\]/isU', $content, $ids))
		{
			$new_ids = array_unique( $ids[ 1 ] );
            foreach ($new_ids as $key => $temp_page_id)
			{
				$link = $database->get_one( "SELECT `link` FROM `" . TABLE_PREFIX . "pages` WHERE `page_id` = " . $temp_page_id );
                if (!is_null($link))
				{
                    $content = str_replace($ids[0][$key], $this->buildPageLink($link), $content);
				}
			}
			unset($temp_page_id);
		}
		
		// as a fallback for links < L* 5, lepton-link is deprecated
        if (preg_match_all('/\[wblink([0-9]+)\]/isU', $content, $ids))
		{
            echo(LEPTON_tools::display('wblink will be removed in L* 6.1.0, please use LEPTONlink instead in internal links!', 'pre', 'ui red message'));
            $new_ids = array_unique($ids[1]);
            foreach ($new_ids as $key => $temp_page_id)
			{
                $link = $database->get_one("SELECT `link` FROM `" . TABLE_PREFIX . "pages` WHERE `page_id` = " . $temp_page_id);
                if (!is_null($link))
				{
                    $content = str_replace($ids[0][$key], $this->buildPageLink($link), $content);
				}
			}
			unset($temp_page_id);
		}
	}

    /**
     * This is necessary if, for example, the views of search results.
     *
     * @return void
     */
    public function maintainConstants(): void
    {
        $lookFor = [
            "DESCRIPTION" => WEBSITE_DESCRIPTION,
            "KEYWORDS" => WEBSITE_KEYWORDS
        ];

        foreach ($lookFor as $key => $value)
        {
            if (!defined($key))
            {
                define($key, $value);
            }
        }
    }
}
