<?php

/**
 * This file is part of LEPTON Core, released under the GNU GPL
 * Please see LICENSE and COPYING files in your package for details, specially for terms and warranties.
 * 
 * NOTICE:LEPTON CMS Package has several different licenses.
 * Please see the individual license in the header of each single file or info.php of modules and templates.
 *
 * @author          LEPTON Project
 * @copyright       2010-2023 LEPTON Project
 * @link            https://lepton-cms.org
 * @license         https://gnu.org/licenses/gpl-3.0.html
 * @license_terms   please see LICENSE and COPYING files in your package
 *
 */

// include class.secure.php to protect this file and the whole CMS!
if(!defined("SEC_FILE")){define("SEC_FILE",'/framework/class.secure.php' );}
if (defined('LEPTON_PATH')) {	
	include LEPTON_PATH.SEC_FILE;
} else {
	$oneback = "../";
	$root = $oneback;
	$level = 1;
	while (($level < 10) && (!file_exists($root.SEC_FILE))) {
		$root .= $oneback;
		$level += 1;
	}
	if (file_exists($root.SEC_FILE)) { 
		include $root.SEC_FILE;  
	} else {
		trigger_error(sprintf("[ %s ] Can't include class.secure.php!", $_SERVER['SCRIPT_NAME']), E_USER_ERROR);
	}
}
// end include class.secure.php

/**
 *	definitions for LEPTON
 *
 */
if (!defined('CORE'))
{
    define('CORE', 'LEPTON');
}

if ((!defined('LEPTON_INSTALL')) && (!defined('LEPTON_VERSION')))
{
    $lep_version = LEPTON_database::getInstance()->get_one('SELECT value from ' . TABLE_PREFIX . 'settings WHERE name = "lepton_version"');
    define('LEPTON_VERSION', $lep_version);
}

/**
 * Constants used in field 'status-flags' of table 'users'
 */
const USERS_DELETED             =  1; // User marked as deleted
const USERS_ACTIVE              =  2; // User is activated
const USERS_CAN_SETTINGS        =  4; // User can change own settings
const USERS_CAN_SELF_DELETE     =  8; // User can delete himself
const USERS_PROFILE_ALLOWED     = 16; // User can create a profile page
const USERS_PROFILE_AVAIL       = 32; // User has fulfilled profile and can not be deleted via core
const USERS_DEFAULT_SETTINGS    = USERS_ACTIVE | USERS_CAN_SETTINGS;  // provided as status-flags = 6 in users table

if (!defined('LEPTON_INSTALL'))
{
    /**
     *    Setting the correct default timezone
     *    to avoid "date" conflicts and warnings
     */
    $timezone_string = ($_SESSION['TIMEZONE_STRING'] ?? DEFAULT_TIMEZONE_STRING);
    date_default_timezone_set($timezone_string);
 
    // Get users date format
    define('DATE_FORMAT', ($_SESSION['DATE_FORMAT'] ?? DEFAULT_DATE_FORMAT));

    // Get users time format
    define('TIME_FORMAT', ($_SESSION['TIME_FORMAT'] ?? DEFAULT_TIME_FORMAT));

    // Set Theme dir
    define('THEME_URL', LEPTON_URL . '/templates/' . DEFAULT_THEME);
    define('THEME_PATH', LEPTON_PATH . '/templates/' . DEFAULT_THEME);

    // Set Module dir
    define('MODULE_URL', LEPTON_URL . '/modules');
    define('MODULE_PATH', LEPTON_PATH . '/modules');

    // Set Secure dir
    define('SECURE_URL', LEPTON_URL . '/temp/secure');
    define('SECURE_PATH', LEPTON_PATH . '/temp/secure');

} 
else 
{
   // Set Theme dir
    define('THEME_URL', LEPTON_URL . '/templates/lepsem');
    define('THEME_PATH', LEPTON_PATH . '/templates/lepsem');
}
